##
##  sasl.spec -- OpenPKG RPM Specification
##  Copyright (c) 2000-2003 Cable & Wireless Deutschland GmbH
##  Copyright (c) 2000-2003 The OpenPKG Project <http://www.openpkg.org/>
##  Copyright (c) 2000-2003 Ralf S. Engelschall <rse@engelschall.com>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         sasl
Summary:      Simple Authentication and Security Layer (SASL)
URL:          http://asg.web.cmu.edu/sasl/
Vendor:       Cyrus Project, CMU
Packager:     The OpenPKG Project
Distribution: OpenPKG [PLUS]
Group:        Cryptography
License:      BSD
Version:      2.1.13
Release:      20030531_kolab

#   package options
%option       with_pam    no
%option       with_login  no
%option       with_ldap   no
%option       with_mysql  no

#   list of sources
Source0:      ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/cyrus-sasl-%{version}.tar.gz
Source1:      rc.sasl
Source2:      fsl.sasl
Source3:      saslauthd.conf
Patch0:       sasl.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20030103, db >= 4.1.24, fsl, gcc, openssl
PreReq:       OpenPKG, openpkg >= 20030103, db >= 4.1.24, fsl
%if "%{with_pam}" == "yes"
BuildPreReq:  PAM
PreReq:       PAM
%endif
%if "%{with_ldap}" == "yes"
BuildPreReq:  openldap
%endif
%if "%{with_mysql}" == "yes"
BuildPreReq:  MYSQL
%endif
AutoReq:      no
AutoReqProv:  no

%description
    SASL is the Simple Authentication and Security Layer, a method
    for adding authentication support to connection-based protocols.
    To use SASL, a protocol includes a command for identifying and
    authenticating a user to a server and for optionally negotiating
    protection of subsequent protocol interactions. If its use is
    negotiated, a security layer is inserted between the protocol and
    the connection.

%prep
    %setup -q -n cyrus-sasl-%{version}
    %patch -p0

%build
    #   disable some unwanted configure checks
    %{l_shtool} subst \
        -e 's;^ *for dbname in ;for dbname in db ;' \
        -e "s;javac;javac-xxx;g" \
        -e "s;javah;javah-xxx;g" \
        -e "s;javadoc;javadoc-xxx;g" \
        configure

    #   fix OpenLDAP support
%if "%{with_ldap}" == "yes"
    echo 'ac_cv_lib_ldap_ldap_initialize=yes' >config.cache
    %{l_shtool} subst \
        -e "s;-lldap -llber;-lldap -llber -lssl -lcrypto;" \
        saslauthd/configure
%endif

    #   configure path to sasl-server config files
    %{l_shtool} subst \
        -e 's;@l_sysconfdir@;%{l_prefix}/etc/sasl/apps;g' \
        lib/server.c

    #   determine build flags
    cflags="%{l_cflags -O} %{l_cppflags}"
    ldflags="%{l_ldflags} `%{l_prefix}/bin/fsl-config --all --ldflags`"
    libs="-ldb `%{l_prefix}/bin/fsl-config --all --libs`"
%if "%{with_ldap}" == "yes"
    cflags="$cflags -DAUTH_LDAP"
%endif
%if "%{with_mysql}" == "yes"
    libs="$libs -lz -lm"
%endif

    #   configure package
    CC="%{l_cc}" \
    CFLAGS="$cflags" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="$ldflags" \
    LIBS="$libs" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir="%{l_prefix}/etc/sasl" \
        --with-plugindir=%{l_prefix}/lib/sasl \
        --with-saslauthd=%{l_prefix}/var/sasl/saslauthd \
        --with-dbpath=%{l_prefix}/var/sasl/sasldb \
        --with-dblib=berkeley \
        --with-bdb-incdir=%{l_prefix}/include \
        --with-bdb-libdir=%{l_prefix}/lib \
%if "%{with_pam}" == "yes"
        --with-pam \
%else
        --without-pam \
%endif
%if "%{with_login}" == "yes"
        --enable-login \
%else
        --disable-login \
%endif
%if "%{with_ldap}" == "yes"
        --with-ldap=%{l_prefix} \
        --without-openssl \
%else
        --without-ldap \
        --without-openssl \
%endif
%if "%{with_mysql}" == "yes"
        --with-mysql=%{l_prefix} \
%else
        --without-mysql \
%endif
        --enable-shared \
        --enable-static \
        --enable-staticdlopen \
        --disable-java \
        --disable-sample \
        --disable-krb4 \
        --disable-gssapi \
        --disable-otp \
        --without-des \
        --without-opie

    #   post adjustment: trust me, libtool, I know what I am doing
    %{l_shtool} subst \
        -e 's;^\(deplibs_check_method=\).*;\1"pass_all";' \
        libtool
    #   post adjustment: do not reference static plugins
    %{l_shtool} subst \
        -e '58s;.*;#define PIC;' \
        lib/dlopen.c
    #   post adjustment: do not pull static plugins into static library
    %{l_shtool} subst \
        -e '/^SASL_STATIC_OBJS/s;\.\./plugins/[^ ]* *;;g' \
        lib/Makefile
    #   post adjustment: build utils against static library
    %{l_shtool} subst \
        -e 's;\(\$(CCLD)\);\1 -static;' \
        utils/Makefile

    #   build package
    %{l_make} %{l_mflags}
    cd saslauthd
    %{l_make} %{l_mflags} testsaslauthd

%install
    rm -rf $RPM_BUILD_ROOT

    #   install package
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   remove libtool cruft
    rm -f \
        $RPM_BUILD_ROOT%{l_prefix}/lib/*.la \
        $RPM_BUILD_ROOT%{l_prefix}/lib/*.so \
        $RPM_BUILD_ROOT%{l_prefix}/lib/*.so.* \
        $RPM_BUILD_ROOT%{l_prefix}/lib/sasl2/*.la \
        $RPM_BUILD_ROOT%{l_prefix}/lib/sasl2/*.a

    #   post-adjust installation
    mv $RPM_BUILD_ROOT%{l_prefix}/lib/sasl2 \
       $RPM_BUILD_ROOT%{l_prefix}/lib/sasl
    strip $RPM_BUILD_ROOT%{l_prefix}/sbin/* >/dev/null 2>&1 || true

    #   install saslauthd test program
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin
    %{l_shtool} install -c -m 755 \
        saslauthd/testsaslauthd \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install saslauthd default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/sasl
    %{l_shtool} install -c -m 755 \
        %{SOURCE saslauthd.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/sasl/

    #   install missing manual pages
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8
    %{l_shtool} install -c -m 644 \
        utils/saslpasswd2.8 \
        utils/sasldblistusers2.8 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8/

    #   create necessary additional directories
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/sasl/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/sasl/saslauthd \
        $RPM_BUILD_ROOT%{l_prefix}/etc/sasl/apps

    #   install run-command script
%if "%{with_pam}" == "yes"
    l_authmech="pam"
%else
    case "%{l_target}" in
        *-linux* | *-solaris* ) l_authmech="shadow"   ;;
        *                     ) l_authmech="getpwent" ;;
    esac
%endif
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 \
        -e "s;@l_authmech@;${l_authmech};g" \
        -e 's;@l_prefix@;%{l_prefix};g' \
        -e 's;@l_susr@;%{l_susr};g' \
        %{SOURCE rc.sasl} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 \
        -e 's;@l_prefix@;%{l_prefix};g' \
        %{SOURCE fsl.sasl} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/fsl.sasl' \
        '%not %dir %{l_prefix}/etc/fsl' \
        '%config %{l_prefix}/etc/sasl/saslauthd.conf' \
        '%dir %attr(0750,%{l_musr},%{l_rgrp}) %{l_prefix}/var/sasl' \
        '%dir %attr(0750,%{l_musr},%{l_rgrp}) %{l_prefix}/var/sasl/saslauthd' \
        '%dir %attr(0700,%{l_susr},%{l_sgrp}) %{l_prefix}/var/sasl/log'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

